/* Aisle tables */
--   aisledetail to tie aisles to stores.  hidden aisles have a sequence number of -1
--   also denormalize the category id from the aislenames table.
CREATE TABLE aisledetail (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'storeid' INTEGER NOT NULL,
    'aislenameid' INTEGER NOT NULL,
    'sequence' INTEGER NOT NULL,
    'uuid' TEXT UNIQUE,
    'modtime' INTEGER NOT NULL,
    'categoryid' INTEGER
);
CREATE INDEX aisledetail_storeid_idx
    ON aisledetail (storeid);
CREATE INDEX aisledetail_store_cat_idx
    ON aisledetail (storeid, categoryid);

--   aislenames something of a misnomer since this table actually contains all relevant aisle data. category id is -1 for user categories.
CREATE TABLE aislenames (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'categoryid' INTEGER,
    'name' TEXT NULL,
    'uuid' TEXT UNIQUE
);

/* List tables */
--   list item packages  
CREATE TABLE listitempackage (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'itemid' INTEGER NOT NULL,
    'units' TEXT,
    'uom' INTEGER,
    'container' TEXT,
    'c_units' TEXT,
    'c_uom' INTEGER,
    'c_container' TEXT,
    'upc' TEXT,
    'selected' INTEGER NOT NULL DEFAULT 0,
    'uuid' TEXT UNIQUE
);
CREATE INDEX listitempkg_itemid_idx
    ON listitempackage (itemid);

--   list items, holding packages
CREATE TABLE listitems (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'modtime' INTEGER NOT NULL,
    'categoryid' INTEGER NOT NULL,
    'quantity' INTEGER NOT NULL DEFAULT 1,
    'brand' TEXT,
    'line' TEXT,
    'name' TEXT,
    'description' TEXT,
    'note' TEXT,
    'attrchoices' TEXT,
    'attrvalues' TEXT,
    'checked' INTEGER NOT NULL DEFAULT 0,
    'cleared' INTEGER NOT NULL DEFAULT 0,
    'deleted' INTEGER NOT NULL DEFAULT 0,
    'favorite' INTEGER NOT NULL DEFAULT 0,
    'storeid' INTEGER DEFAULT NULL,
    'priceperqty' INT,
    'priceperweight' INT,
    'weight' TEXT,
    'usingweight' INT NOT NULL DEFAULT 0,
    'displaytitle' TEXT COLLATE NOCASE,
    'displaysubtitle' TEXT COLLATE NOCASE,
    'uuid' TEXT UNIQUE,
    'dedupid' INT NOT NULL DEFAULT 0,
    'usercoupon' INTEGER NOT NULL DEFAULT 0,
    'searchid' INTEGER NOT NULL DEFAULT 0,
    'offersavailable' INTEGER NOT NULL DEFAULT 0
);
CREATE INDEX listitems_deleted_idx
    ON listitems (deleted);
CREATE INDEX listitems_display_names_idx
    ON listitems (displaytitle, displaysubtitle);
CREATE INDEX listitems_dupdetect_idx
    ON listitems (displaytitle, displaysubtitle, categoryid, deleted, cleared);
CREATE INDEX listitems_listitemspeed1_idx
    ON listitems (deleted, cleared, favorite);
CREATE INDEX listitems_storeid_idx
    ON listitems (storeid);

--   disallow duplicates
CREATE UNIQUE INDEX listitems_unique_idx
    ON listitems (displaytitle, displaysubtitle, categoryid, storeid, cleared, favorite, dedupid);

--   listoffers table
--   note images for listoffers will be stored as <couponid>.<extension>
CREATE TABLE listoffers (
    'id' INTEGER PRIMARY KEY NOT NULL,
    'offerid' INTEGER NOT NULL,
    'value' INTEGER NOT NULL DEFAULT 0,
    'type' INTEGER NOT NULL,
    'brand' TEXT,
    'summary' TEXT,
    'l1text' TEXT,
    'l2text' TEXT,
    'categoryid' INTEGER NOT NULL,
    'categorydesc' TEXT,
    'expirationdate' REAL,
    'activedate' REAL,
    'slot' INTEGER NOT NULL,
    'uuid' TEXT UNIQUE,
    'redemption_limit_text' TEXT,
    'stc_disclaimer' TEXT,
    'imageUrl' TEXT,
    'cpn_state' INTEGER NOT NULL DEFAULT 0,
    'sc_state' INTEGER NOT NULL DEFAULT 0
);

/* Stores data */
--   stores to hold aisles
CREATE TABLE stores (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'modtime' INTEGER NOT NULL,
    'deleted' INTEGER NOT NULL DEFAULT 0,
    'name' TEXT NOT NULL,
    'storeitemsonly' INTEGER NOT NULL DEFAULT 0,
    'uuid' TEXT UNIQUE,
    'sequence' INTEGER NOT NULL DEFAULT -1
);

/* User Lists */
--   list of users we share our list with
CREATE TABLE users (
    'id' INTEGER NOT NULL PRIMARY KEY,
    'name' TEXT,
    'email' TEXT NOT NULL
);

/* Create table for enabling enhanced universal search */
CREATE VIRTUAL TABLE enhancedsearch USING fts3 (
    brand TEXT, 
    description TEXT
);

/* Table for tracking offers that match list items */
CREATE TABLE offersforlistitems (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'listitemid' INTEGER NOT NULL,
    'offerid' INTEGER NOT NULL,
    'cpn_state' INTEGER NOT NULL DEFAULT 0
);
CREATE INDEX offersforitems_listitemid_idx ON offersforlistitems (listitemid);
CREATE INDEX offersforitems_offerid_idx ON offersforlistitems (offerid);