/* Upgrade script from schema 11.03 to 11.04*/

/* Offers tables */
--   Drop offers table. It now lives in the Offers Provider.
DROP TABLE IF EXISTS offers;

/* featured items */
--   Drop featured programs table and index. It now lives in the Offers Provider.
DROP TABLE IF EXISTS featuredprograms;
DROP INDEX IF EXISTS featuredprograms_idx1;

/* Create table for enabling enhanced universal search */
CREATE VIRTUAL TABLE enhancedsearch USING fts3 (
    brand TEXT, 
    description TEXT
);

ALTER TABLE stores ADD COLUMN 'sequence' INTEGER NOT NULL DEFAULT -1;

/* Set the initial sequence values */
UPDATE stores SET sequence=id;

ALTER TABLE listitems ADD COLUMN 'searchid' INTEGER NOT NULL DEFAULT 0;
ALTER TABLE listitems ADD COLUMN 'offersavailable' INTEGER NOT NULL DEFAULT 0;

ALTER TABLE listoffers ADD COLUMN 'l2text' TEXT;
ALTER TABLE listoffers ADD COLUMN 'redemption_limit_text' TEXT;
ALTER TABLE listoffers ADD COLUMN 'stc_disclaimer' TEXT;
ALTER TABLE listoffers ADD COLUMN 'imageUrl' TEXT;
ALTER TABLE listoffers ADD COLUMN 'cpn_state' INTEGER NOT NULL DEFAULT 0;
ALTER TABLE listoffers ADD COLUMN 'sc_state' INTEGER NOT NULL DEFAULT 0;

/* On upgrade default offer states to Emailed/Added to card because before 
 * this release that was the only way an offer would be visible on a users
 * list. Make sure the numeric values match the enum values of OfferState
 */
UPDATE listoffers SET cpn_state=5, sc_state=3;

/* Table for tracking offers that match list items */
CREATE TABLE offersforlistitems (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'listitemid' INTEGER NOT NULL,
    'offerid' INTEGER NOT NULL,
    'cpn_state' INTEGER NOT NULL DEFAULT 0
);
CREATE INDEX offersforitems_listitemid_idx ON offersforlistitems (listitemid);
CREATE INDEX offersforitems_offerid_idx ON offersforlistitems (offerid);